# `RGBMatrixEmulator`

`RGBMatrixEmulator` is a Python package for emulating RGB LED matrices that are normally driven by the [`rpi-rgb-led-matrix`](https://github.com/hzeller/rpi-rgb-led-matrix) library. Most commonly, these are used with single-board computers such as the Raspberry Pi.

`RGBMatrixEmulator` (currently) supports a subset of the function calls present in the Python bindings for `rpi-rgb-led-matrix`. As such, it's accuracy is not 100% guaranteed.

## Installation

`RGBMatrixEmulator` is in the [Python Package Index (PyPI)](http://pypi.python.org/pypi/RGBMatrixEmulator/).
Installing with ``pip`` is recommended for all systems.

```sh
pip install RGBMatrixEmulator
```

## Contact

Tyler Porter

tyler.b.porter@gmail.com